@@ -6,14 +6,9 @@ requireLevel <- function(requiredLevel) {
 }
 
 skipall <- if (requireNamespace("rscala", quietly = TRUE)) {
-  if ( ! isTRUE(tryCatch({rscala::scalaConfig(reconfig="offline")}, error=function(e) TRUE)) ) {
-    cat(paste0("************ Starting tests at level ",TEST_LEVEL," (extensive=",TEST_EXTENSIVE,"). ************\n"))
-    library(aibd)
-    FALSE
-  } else {
-    cat("Scala does not seem to be available. ********************************\n")
-    TRUE
-  }
+  cat(paste0("************ Starting tests at level ",TEST_LEVEL," (extensive=",TEST_EXTENSIVE,"). ************\n"))
+  library(aibd)
+  FALSE
 } else {
   cat("rscala is not installed. ********************************\n")
   TRUE
